@@ -1,4 +1,4 @@
-__version__ = '0.7.2'
+__version__ = '1.0.0'
 
 import fullmetalalchemy.create as create
 import fullmetalalchemy.delete as delete
@@ -10,6 +10,4 @@ import fullmetalalchemy.update as update
 import fullmetalalchemy.type_convert as type_convert
 import fullmetalalchemy.records as records
 from fullmetalalchemy.create import create_engine
-from fullmetalalchemy.features import get_table, get_table_names, get_engine_table
-from fullmetalalchemy.table import Table
-from fullmetalalchemy.sessiontable import SessionTable
\ No newline at end of file
+from fullmetalalchemy.features import get_table, get_table_names, get_engine_table
\ No newline at end of file
